changeset 22946:d3b26055bfa8 v8.2.2020

patch 8.2.2020: some compilers do not like the "namespace" argument Commit: https://github.com/vim/vim/commit/bebaa0d5c034eb2c4c4dcac86ae6a859b24d2693 Author: Bram Moolenaar <Bram@vim.org> Date: Fri Nov 20 18:59:19 2020 +0100 patch 8.2.2020: some compilers do not like the "namespace" argument Problem: Some compilers do not like the "namespace" argument. Solution: Rename to "use_namespace". (closes https://github.com/vim/vim/issues/7332)
author Bram Moolenaar <Bram@vim.org>
date Fri, 20 Nov 2020 19:00:03 +0100
parents a058f2c5ce98
children 8625a16d18dc
files src/proto/vim9compile.pro src/version.c src/vim9compile.c
diffstat 3 files changed, 6 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/src/proto/vim9compile.pro
+++ b/src/proto/vim9compile.pro
@@ -8,7 +8,7 @@ imported_T *find_imported_in_script(char
 int vim9_comment_start(char_u *p);
 char_u *peek_next_line_from_context(cctx_T *cctx);
 char_u *next_line_from_context(cctx_T *cctx, int skip_comment);
-char_u *to_name_end(char_u *arg, int namespace);
+char_u *to_name_end(char_u *arg, int use_namespace);
 char_u *to_name_const_end(char_u *arg);
 exptype_T get_compare_type(char_u *p, int *len, int *type_is);
 void error_white_both(char_u *op, int len);
--- a/src/version.c
+++ b/src/version.c
@@ -751,6 +751,8 @@ static char *(features[]) =
 static int included_patches[] =
 {   /* Add new patch number below this line */
 /**/
+    2020,
+/**/
     2019,
 /**/
     2018,
--- a/src/vim9compile.c
+++ b/src/vim9compile.c
@@ -2767,12 +2767,12 @@ theend:
 /*
  * Find the end of a variable or function name.  Unlike find_name_end() this
  * does not recognize magic braces.
  * When "namespace" is TRUE recognize "b:", "s:", etc.
  * Return a pointer to just after the name.  Equal to "arg" if there is no
  * valid name.
  */
     char_u *
-to_name_end(char_u *arg, int namespace)
+to_name_end(char_u *arg, int use_namespace)
 {
     char_u	*p;
 
@@ -2784,7 +2784,7 @@ to_name_end(char_u *arg, int namespace)
 	// Include a namespace such as "s:var" and "v:var".  But "n:" is not
 	// and can be used in slice "[n:]".
 	if (*p == ':' && (p != arg + 1
-			     || !namespace
+			     || !use_namespace
 			     || vim_strchr(VIM9_NAMESPACE_CHAR, *arg) == NULL))
 	    break;
     return p;
@@ -2767,12 +2767,12 @@ theend:
  * Find the end of a variable or function name.  Unlike find_name_end() this
  * does not recognize magic braces.
- * When "namespace" is TRUE recognize "b:", "s:", etc.
+ * When "use_namespace" is TRUE recognize "b:", "s:", etc.
  * Return a pointer to just after the name.  Equal to "arg" if there is no
  * valid name.